
::: {.cell 0=‘h’ 1=‘i’ 2=‘d’ 3=‘e’}

``` python
from sql_face.core import *
```

:::

# sql-face

> Saves face image attributes in SQL database.

This file will become your README and also the index of your
documentation.

## Install

``` sh
pip install sql_face
```

## How to use

Fill me in please! Don’t forget code examples:

``` python
1+1
```

    2
